#
# spec file for package python-softlayer
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-softlayer
Version:        5.8.0
Release:        bp155.2.14
Summary:        A set of Python libraries that assist in calling the SoftLayer API
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/softlayer/softlayer-python
Source:         https://github.com/softlayer/softlayer-python/archive/v%{version}.tar.gz
BuildRequires:  %{python_module PrettyTable >= 0.7.0}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module prompt_toolkit >= 2}
BuildRequires:  %{python_module pygments >= 2.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.0}
BuildRequires:  %{python_module testtools}
BuildRequires:  %{python_module urllib3 >= 1.24}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PrettyTable >= 0.7.0
Requires:       python-click
Requires:       python-prompt_toolkit >= 2
Requires:       python-pygments >= 2.0.0
Requires:       python-requests >= 2.20.0
Requires:       python-setuptools
Requires:       python-six >= 1.7.0
Requires:       python-urllib3 >= 1.24
%python_subpackages

%description
This library provides a simple Python client to interact with SoftLayer's XML-RPC API.

%prep
%setup -q -n softlayer-python-%{version}

%build
%python_build

%install
%python_install
# do not install tests
%python_expand rm -r %{buildroot}%{$python_sitelib}/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc *.md
%{python_sitelib}/*
%python3_only %{_bindir}/sl
%python3_only %{_bindir}/slcli

%changelog
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Bump to 5.8.0:
  * use prompt_toolkit >= 2.0
  * various tests/documentation improvements
  * Removed legacy loadbalancer command
* Tue May  7 2019 pgajdos@suse.com
- version update to 5.7.2
  + #1107 Added exception to handle json parsing error when ordering
  + #1068 Support for -1 when changing port speed
  + #1109 Fixed docs about placement groups
  + #1112 File storage endurance iops upgrade
  + #1101 Handle the new user creation exceptions
  + #1116 Fix order place quantity option
  + #1002 Invoice commands
  * account invoices
  * account invoice-detail
  * account summary
  + #1004 Event Notification Management commands
  * account events
  * account event-detail
  + #1117 Two PCIe items can be added at order time
  + #1121 Fix object storage apiType for S3 and Swift.
  + #1100 Event Log performance improvements.
  + #872 column 'name' was renamed to 'hostname'
  + #1127 Fix object storage credentials.
  + #1129 Fixed unexpected errors in slcli subnet create
  + #1134 Change encrypt parameters for importing of images. Adds root-key-crn
  + #208 Quote ordering commands
  * order quote
  * order quote-detail
  * order quote-list
  + #1113 VS usage information command
  * virtual usage
  + #1131 made sure config_tests dont actually make api calls.
- deleted patches
  - python-softlayer-fix-teset_setup_cancel.patch (upstreamed)
* Thu Apr 25 2019 pgajdos@suse.com
- added patches
  fix https://github.com/softlayer/softlayer-python/issues/1095
  + python-softlayer-fix-teset_setup_cancel.patch
* Tue Apr  9 2019 pgajdos@suse.com
- version update to 5.7.1
  * many changes, see CHANGELOG.md
- run testsuite
- package change log
* Fri May 11 2018 toddrme2178@gmail.com
- Don't foget python_module workaround.
* Sun Apr 15 2018 tchvatal@suse.com
- Initial commit, needed by python-dns-lexicon
